import React, { useState, useEffect } from "react";
import { ScheduleOutlined, RotateRightOutlined, CheckCircleOutline } from "@material-ui/icons";
import { useCommandJob } from '../../api/SwaggerApi';
import { StepperWithStyle } from "../common/stepper/StepperWithStyle";

export function CommandJobStatus({ awxCommandId, actionType }) {
  const [commandJob, getCommandJob] = useCommandJob(awxCommandId);
  const [activeStep, setActiveStep] = useState(0);

  useEffect(() => {
    if (commandJob) {
      if (!(["successful", "failed"].includes(commandJob.status.toLowerCase()))) {
        if (commandJob.status.toLowerCase() === "running") {
          setActiveStep(1);
        }
        setTimeout(getCommandJob, 3000);
      } else {
        if (commandJob.status.toLowerCase() === "successful") {
          setActiveStep(3);
        }
        if (commandJob.status.toLowerCase() === "failed") {
          setActiveStep(1);
        }
      }
    }
  }, [commandJob, getCommandJob]);

  const icons = {
    1: <ScheduleOutlined />,
    2: <RotateRightOutlined />,
    3: <CheckCircleOutline />,
  };

  const steps = ['Queued ', 'Running', actionType + ' Completed'];

  const isStepFailed = (step) => {
    if (commandJob?.status.toLowerCase() === "failed") {
      return step === activeStep;
    }
    return false;
  };

  return (
    <StepperWithStyle steps={steps} activeStep={activeStep} isStepFailed={isStepFailed} icons={icons}/>
  )
}