import { Container, Grid, Hidden, Paper, FormControlLabel, Switch, Typography, Box } from "@material-ui/core";
import { RootContainer } from "../../components/common/Container/RootContainer";
import React, { useState, useEffect, useContext } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { IOCList } from "../../components/IOC/IOCList";
import { IOCTable } from "../../components/IOC/IOCTable";
import { useIOCSearch, userContext } from "../../api/SwaggerApi";
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams } from "../../components/common/Helper";
import { SearchBar } from "../../components/common/SearchBar/SearchBar";

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
}));

export function IOCListView() {
  const [iocs, getIocs, /*reset*/, loading] = useIOCSearch();
  const [query, setQuery] = useState("");
  const [ownOnly, setOwnOnly] = useState(false);
  const {user} = useContext(userContext);
  const classes = useStyles();

  const [lazyParams, setLazyParams] = useState({
    first: 0,
    rows: 20,
    page: 0
  });
  
  const [columnSort, setColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  const handleChangeOwn = (event) => {
    const own = event.target.checked;
    setOwnOnly(own);
  };

  const rowsPerPage = [5, 10, 20, 50, 100];
  
  console.log("rendering Explore IOCs")

  useEffect(() => {
    let requestParams = initRequestParams(lazyParams, query, columnSort);
    
    if(ownOnly) {
      requestParams.owner = user?.loginName;
    }

    if(columnSort.sortField === "owner") {
      requestParams.orderBy = "OWNER";
    }
  
    if(columnSort.sortField === "namingName") {
      requestParams.orderBy = "IOC_NAME";
    }
  
    if(columnSort.sortField === "sourceVersion") {
      requestParams.orderBy = "GIT_REFERENCE";
    }

    getIocs(requestParams);
  }, [getIocs, lazyParams, columnSort, query, user, ownOnly])

  const title = "Explore IOCs";
  useGlobalAppBar(title);

  let content = (
    <SearchBar search={setQuery} loading={loading}>
      <Hidden smUp>
        <IOCList iocs={iocs.iocList}/>
      </Hidden>
      <Hidden xsDown>
        <IOCTable iocs={iocs.iocList} loading={loading} rowType="explore" 
          lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort} totalCount={iocs.totalCount} 
          rowsPerPage={rowsPerPage} />
      </Hidden>
    </SearchBar>
  );

  return (
    <RootContainer>
      <Container>
        <Paper className={classes.root}>
          <Grid container spacing={1}>
            <Grid item xs={12} md={12}>
            <Box display="flex" justifyContent="end" p={2} m={1}>
              <FormControlLabel className={classes.formControl}
                control={<Switch checked={ownOnly} onChange={handleChangeOwn} />}
                label={<Typography variant="h5">My IOCs</Typography>}
              />
              </Box>
            </Grid>
            <Grid item xs={12} md={12}>
              {content}
            </Grid>
          </Grid>
        </Paper>
      </Container>
    </RootContainer>
  );
}

